@@ -26,6 +26,7 @@
 
 #include "gtr-actions.h"
 #include "gtr-application.h"
+#include "gtr-debug.h"
 #include "gtr-dirs.h"
 #include "gtr-header.h"
 #include "gtr-msg.h"
@@ -33,10 +34,11 @@
 #include "gtr-tab.h"
 #include "gtr-plugins-engine.h"
 #include "gtr-po.h"
-#include "gtr-prefs-manager-app.h"
+#include "gtr-settings.h"
 #include "gtr-statusbar.h"
 #include "gtr-utils.h"
 #include "gtr-window.h"
+#include "gtr-window-activatable.h"
 #include "gtr-profile-manager.h"
 #include "gtr-status-combo-box.h"
 
@@ -55,6 +57,7 @@
 #include <glib-object.h>
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
+#include <libpeas/peas-extension-set.h>
 
 #define GTR_STOCK_FUZZY_NEXT "gtranslator-fuzzy-next"
 #define GTR_STOCK_FUZZY_PREV "gtranslator-fuzzy-prev"
@@ -78,6 +81,9 @@ G_DEFINE_TYPE (GtrWindow, gtr_window, GTK_TYPE_WINDOW)
 
 struct _GtrWindowPrivate
 {
+  GSettings *ui_settings;
+  GSettings *state_settings;
+
   GtkWidget *main_box;
 
   GtkWidget *menubar;
@@ -110,7 +116,9 @@ struct _GtrWindowPrivate
   GtrProfileManager *prof_manager;
   GtkWidget *profile_combo;
 
-  gboolean destroy_has_run : 1;
+  PeasExtensionSet *extensions;
+
+  guint dispose_has_run : 1;
 };
 
 enum
@@ -355,12 +363,11 @@ gtr_window_layout_load (GtrWindow * window,
       !gdl_dock_layout_load_from_file (window->priv->layout_manager,
                                        layout_filename))
     {
+      const gchar *datadir;
       gchar *path;
-      gchar *datadir;
 
       datadir = gtr_dirs_get_gtr_data_dir ();
       path = g_build_filename (datadir, "layout.xml", NULL);
-      g_free (datadir);
 
       //DEBUG_PRINT ("Layout = %s", path);
       if (!gdl_dock_layout_load_from_file (window->priv->layout_manager,
@@ -541,7 +548,8 @@ remove_widget (GtrWindow * window, GtkWidget * widget, GError ** error)
 }
 
 void
-set_sensitive_according_to_message (GtrWindow * window, GtrPo * po)
+_gtr_window_set_sensitive_according_to_message (GtrWindow * window,
+                                                GtrPo * po)
 {
   GList *current;
   GtkAction *action;
@@ -598,7 +606,6 @@ set_sensitive_according_to_tab (GtrWindow * window, GtrTab * tab)
   GtrPo *po;
   GtkSourceBuffer *buf;
   GtkAction *action;
-  GList *current;
   GtrPoState state;
   gint pages;
   gint current_page;
@@ -607,7 +614,6 @@ set_sensitive_according_to_tab (GtrWindow * window, GtrTab * tab)
   pages = gtk_notebook_get_n_pages (GTK_NOTEBOOK (window->priv->notebook));
   view = gtr_tab_get_active_view (tab);
   po = gtr_tab_get_po (tab);
-  current = gtr_po_get_current_message (po);
   buf = GTK_SOURCE_BUFFER (gtk_text_view_get_buffer (GTK_TEXT_VIEW (view)));
 
   if (gtk_action_group_get_sensitive (window->priv->action_group) == FALSE)
@@ -653,10 +659,12 @@ set_sensitive_according_to_tab (GtrWindow * window, GtrTab * tab)
                                         "DocumentsNextDocument");
   gtk_action_set_sensitive (action, current_page < pages - 1);
 
-  set_sensitive_according_to_message (window, po);
+  _gtr_window_set_sensitive_according_to_message (window, po);
+
+  peas_extension_set_call (window->priv->extensions, "update_state", window);
 }
 
-void
+static void
 set_sensitive_according_to_window (GtrWindow * window)
 {
   gint pages;
@@ -908,8 +916,7 @@ drag_data_received_cb (GtkWidget * widget,
       locations = gtr_utils_drop_get_locations (selection_data);
       gtr_actions_load_locations (window, locations);
 
-      g_slist_foreach (locations, (GFunc) g_object_unref, NULL);
-      g_slist_free (locations);
+      g_slist_free_full (locations, g_object_unref);
     }
 }
 
@@ -967,7 +974,7 @@ set_window_title (GtrWindow * window, gboolean with_path)
 
 static void
 notebook_switch_page (GtkNotebook * nb,
-                      GtkNotebookPage * page,
+                      GtkWidget * page,
                       gint page_num, GtrWindow * window)
 {
   GtrTab *tab;
@@ -1052,8 +1059,7 @@ notebook_switch_page (GtkNotebook * nb,
   if (action != NULL)
     gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action), TRUE);
 
-  gtr_plugins_engine_update_plugins_ui
-    (gtr_plugins_engine_get_default (), window, FALSE);
+  peas_extension_set_call (window->priv->extensions, "update_state", window);
 }
 
 static void
@@ -1074,6 +1080,8 @@ notebook_page_removed (GtkNotebook * notebook,
     gtk_widget_hide (window->priv->profile_combo);
 
   update_documents_list_menu (window);
+
+  peas_engine_garbage_collect (PEAS_ENGINE (gtr_plugins_engine_get_default ()));
 }
 
 static void
@@ -1084,8 +1092,7 @@ notebook_tab_close_request (GtrNotebook * notebook,
    * seems to be ok, but we need to keep an eye on this. */
   gtr_close_tab (tab, window);
 
-  gtr_plugins_engine_update_plugins_ui
-    (gtr_plugins_engine_get_default (), window, FALSE);
+  peas_extension_set_call (window->priv->extensions, "update_state", window);
 }
 
 static void
@@ -1149,7 +1156,7 @@ showed_message_cb (GtrTab * tab, GtrMsg * msg, GtrWindow * window)
 
   gtr_window_update_statusbar_message_count (tab, msg, window);
 
-  set_sensitive_according_to_message (window, gtr_tab_get_po (tab));
+  _gtr_window_set_sensitive_according_to_message (window, gtr_tab_get_po (tab));
 }
 
 static void
@@ -1206,8 +1213,7 @@ notebook_tab_added (GtkNotebook * notebook,
 
   update_documents_list_menu (window);
 
-  gtr_plugins_engine_update_plugins_ui (gtr_plugins_engine_get_default (),
-                                        window, FALSE);
+  peas_extension_set_call (window->priv->extensions, "update_state", window);
 }
 
 void
@@ -1289,8 +1295,7 @@ gtr_recent_chooser_item_activated_cb (GtkRecentChooser * chooser,
   list = g_slist_prepend (list, location);
 
   gtr_actions_load_locations (window, list);
-  g_slist_foreach (list, (GFunc) g_object_unref, NULL);
-  g_slist_free (list);
+  g_slist_free_full (list, g_object_unref);
 }
 
 static GtkWidget *
@@ -1332,16 +1337,17 @@ gtr_window_cmd_edit_toolbar (GtkAction * action, GtrWindow * window)
 {
   GtkWidget *dialog;
   GtkWidget *editor;
+  GtkWidget *content_area;
 
   dialog = gtk_dialog_new_with_buttons (_("Toolbar Editor"),
                                         GTK_WINDOW (window),
                                         GTK_DIALOG_DESTROY_WITH_PARENT,
                                         GTK_STOCK_CLOSE,
                                         GTK_RESPONSE_CLOSE, NULL);
+  content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
   gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_CLOSE);
   gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (dialog)), 5);
-  gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 2);
-  gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
+  gtk_box_set_spacing (GTK_BOX (content_area), 2);
   gtk_window_set_default_size (GTK_WINDOW (dialog), 500, 400);
 
   editor = egg_toolbar_editor_new (window->priv->ui_manager,
@@ -1351,7 +1357,7 @@ gtr_window_cmd_edit_toolbar (GtkAction * action, GtrWindow * window)
   gtk_container_set_border_width (GTK_CONTAINER (editor), 5);
   gtk_box_set_spacing (GTK_BOX (EGG_TOOLBAR_EDITOR (editor)), 5);
 
-  gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), editor);
+  gtk_box_pack_start (GTK_BOX (content_area), editor, TRUE, TRUE, 0);
 
   egg_editable_toolbar_set_edit_mode
     (EGG_EDITABLE_TOOLBAR (window->priv->toolbar), TRUE);
@@ -1481,6 +1487,8 @@ create_statusbar (GtrWindow *window,
   gtk_widget_show (window->priv->statusbar);
 
   window->priv->profile_combo = gtr_status_combo_box_new (_("Profile"));
+  gtk_widget_set_tooltip_text (window->priv->profile_combo,
+                               _("Profile for the active document"));
   gtk_box_pack_start (GTK_BOX (window->priv->statusbar),
                       window->priv->profile_combo, FALSE, TRUE, 0);
 
@@ -1621,7 +1629,7 @@ gtr_window_draw (GtrWindow * window)
   GError *error = NULL;
   GtkWidget *dockbar;
   GtkActionGroup *action_group;
-  gchar *datadir;
+  const gchar *datadir;
   gchar *path;
 
   GtrWindowPrivate *priv = window->priv;
@@ -1667,7 +1675,6 @@ gtr_window_draw (GtrWindow * window)
 
   datadir = gtr_dirs_get_gtr_data_dir ();
   path = g_build_filename (datadir, "gtranslator-ui.xml", NULL);
-  g_free (datadir);
 
   if (!gtk_ui_manager_add_ui_from_file (priv->ui_manager, path, &error))
     {
@@ -1734,7 +1741,9 @@ gtr_window_draw (GtrWindow * window)
   priv->layout_manager = gdl_dock_layout_new (GDL_DOCK (priv->dock));
   g_object_set (priv->layout_manager->master,
                 "switcher-style",
-                gtr_prefs_manager_get_pane_switcher_style (), NULL);
+                g_settings_get_enum (priv->ui_settings,
+                                     GTR_SETTINGS_PANEL_SWITCHER_STYLE),
+                NULL);
   g_signal_connect (priv->layout_manager,
                     "notify::dirty",
                     G_CALLBACK (on_layout_dirty_notify), window);
@@ -1760,17 +1769,44 @@ gtr_window_draw (GtrWindow * window)
   create_statusbar (window, hbox);
 }
 
+static void
+extension_added (PeasExtensionSet *extensions,
+                 PeasPluginInfo   *info,
+                 PeasExtension    *exten,
+                 GtrWindow        *window)
+{
+  peas_extension_call (exten, "activate");
+}
+
+static void
+extension_removed (PeasExtensionSet *extensions,
+                   PeasPluginInfo   *info,
+                   PeasExtension    *exten,
+                   GtrWindow        *window)
+{
+  peas_extension_call (exten, "deactivate");
+
+  /* Ensure update of ui manager, because we suspect it does something
+   * with expected static strings in the type module (when unloaded the
+   * strings don't exist anymore, and ui manager updates in an idle
+   * func) */
+  gtk_ui_manager_ensure_update (window->priv->ui_manager);
+}
+
 static void
 gtr_window_init (GtrWindow * window)
 {
   GtkTargetList *tl;
   GtkWidget *view_menu;
+  const gchar *config_folder;
   gchar *filename;
-  gchar *config_folder;
 
   window->priv = GTR_WINDOW_GET_PRIVATE (window);
 
-  window->priv->destroy_has_run = FALSE;
+  window->priv->ui_settings = g_settings_new ("org.gnome.gtranslator.preferences.ui");
+  window->priv->state_settings = g_settings_new ("org.gnome.gtranslator.state.window");
+
+  window->priv->dispose_has_run = FALSE;
 
   /* Profile manager */
   window->priv->prof_manager = gtr_profile_manager_get_default ();
@@ -1820,10 +1856,6 @@ gtr_window_init (GtrWindow * window)
   window->priv->view_menu =
     gtk_menu_item_get_submenu (GTK_MENU_ITEM (view_menu));
 
-  /* Plugins */
-  gtr_plugins_engine_update_plugins_ui
-    (gtr_plugins_engine_get_default (), window, TRUE);
-
   /* Adding notebook to dock */
   add_widget_full (window,
                    window->priv->notebook,
@@ -1834,10 +1866,42 @@ gtr_window_init (GtrWindow * window)
   /* Loading dock layout */
   config_folder = gtr_dirs_get_user_config_dir ();
   filename = g_build_filename (config_folder, "gtr-layout.xml", NULL);
-  g_free (config_folder);
 
   gtr_window_layout_load (window, filename, NULL);
   g_free (filename);
+
+  /* Plugins */
+  window->priv->extensions = peas_extension_set_new (PEAS_ENGINE (gtr_plugins_engine_get_default ()),
+                                                     GTR_TYPE_WINDOW_ACTIVATABLE,
+                                                     "window", window,
+                                                     NULL);
+  g_signal_connect (window->priv->extensions,
+                    "extension-added",
+                    G_CALLBACK (extension_added),
+                    window);
+  g_signal_connect (window->priv->extensions,
+                    "extension-removed",
+                    G_CALLBACK (extension_removed),
+                    window);
+  peas_extension_set_call (window->priv->extensions, "activate");
+}
+
+static void
+save_panes_state (GtrWindow * window)
+{
+  const gchar *config_folder;
+  gchar *filename;
+
+  g_settings_set (window->priv->state_settings, GTR_SETTINGS_WINDOW_SIZE, "(ii)",
+                  window->priv->width, window->priv->height);
+  g_settings_set_int (window->priv->state_settings, GTR_SETTINGS_WINDOW_STATE,
+                      window->priv->window_state);
+
+  config_folder = gtr_dirs_get_user_config_dir ();
+  filename = g_build_filename (config_folder, "gtr-layout.xml", NULL);
+
+  gtr_window_layout_save (window, filename, NULL);
+  g_free (filename);
 }
 
 static void
@@ -1848,6 +1912,36 @@ gtr_window_dispose (GObject * object)
 
   DEBUG_PRINT ("window dispose");
 
+  /* First of all, force collection so that plugins
+   * really drop some of the references.
+   */
+  peas_engine_garbage_collect (PEAS_ENGINE (gtr_plugins_engine_get_default ()));
+
+  if (!priv->dispose_has_run)
+    {
+      save_panes_state (window);
+
+      /* Note that unreffing the extensions will automatically remove
+         all extensions which in turn will deactivate the extension */
+      g_object_unref (priv->extensions);
+
+      peas_engine_garbage_collect (PEAS_ENGINE (gtr_plugins_engine_get_default ()));
+
+      priv->dispose_has_run = TRUE;
+    }
+
+  if (priv->ui_settings)
+    {
+      g_object_unref (priv->ui_settings);
+      priv->ui_settings = NULL;
+    }
+
+  if (priv->state_settings)
+    {
+      g_object_unref (priv->state_settings);
+      priv->state_settings = NULL;
+    }
+
   if (priv->ui_manager)
     {
       g_object_unref (priv->ui_manager);
@@ -1865,10 +1959,22 @@ gtr_window_dispose (GObject * object)
       priv->prof_manager = NULL;
     }
 
+  if (priv->widgets)
+    {
+      g_hash_table_unref (priv->widgets);
+      priv->widgets = NULL;
+    }
+
+  if (priv->layout_manager)
+    {
+      g_object_unref (priv->layout_manager);
+      priv->layout_manager = NULL;
+    }
+
   /* Now that there have broken some reference loops,
    * force collection again.
    */
-  gtr_plugins_engine_garbage_collect (gtr_plugins_engine_get_default ());
+  peas_engine_garbage_collect (PEAS_ENGINE (gtr_plugins_engine_get_default ()));
 
   G_OBJECT_CLASS (gtr_window_parent_class)->dispose (object);
 }
@@ -1876,61 +1982,11 @@ gtr_window_dispose (GObject * object)
 static void
 gtr_window_finalize (GObject * object)
 {
+  DEBUG_PRINT ("Finalize window");
+
   G_OBJECT_CLASS (gtr_window_parent_class)->finalize (object);
 }
 
-static void
-save_panes_state (GtrWindow * window)
-{
-  gchar *filename;
-  gchar *config_folder;
-
-  if (gtr_prefs_manager_window_size_can_set ())
-    gtr_prefs_manager_set_window_size (window->priv->width,
-                                       window->priv->height);
-
-  if (gtr_prefs_manager_window_state_can_set ())
-    gtr_prefs_manager_set_window_state (window->priv->window_state);
-
-  config_folder = gtr_dirs_get_user_config_dir ();
-  filename = g_build_filename (config_folder, "gtr-layout.xml", NULL);
-  g_free (config_folder);
-
-  gtr_window_layout_save (window, filename, NULL);
-  g_free (filename);
-}
-
-static void
-gtr_window_destroy (GtkObject * object)
-{
-  GtrWindow *window;
-
-  window = GTR_WINDOW (object);
-
-  DEBUG_PRINT ("Destroy window");
-
-  if (!window->priv->destroy_has_run)
-    {
-      save_panes_state (window);
-
-      if (window->priv->widgets)
-        {
-          g_hash_table_destroy (window->priv->widgets);
-          window->priv->widgets = NULL;
-        }
-
-      if (window->priv->layout_manager)
-        {
-          g_object_unref (window->priv->layout_manager);
-          window->priv->layout_manager = NULL;
-        }
-      window->priv->destroy_has_run = TRUE;
-    }
-
-  GTK_OBJECT_CLASS (gtr_window_parent_class)->destroy (object);
-}
-
-
 static gboolean
 gtr_window_configure_event (GtkWidget * widget, GdkEventConfigure * event)
 {
@@ -1943,11 +1999,47 @@ gtr_window_configure_event (GtkWidget * widget, GdkEventConfigure * event)
                                                                       event);
 }
 
+#if 0
+FIXME: for now we are giving priority to the window accels
+/*
+ * GtkWindow catches keybindings for the menu items _before_ passing them to
+ * the focused widget. This is unfortunate and means that pressing ctrl+V
+ * in an entry on a panel ends up pasting text in the TextView.
+ * Here we override GtkWindow's handler to do the same things that it
+ * does, but in the opposite order and then we chain up to the grand
+ * parent handler, skipping gtk_window_key_press_event.
+ */
+static gboolean
+gtr_window_key_press_event (GtkWidget   *widget,
+                            GdkEventKey *event)
+{
+  static gpointer grand_parent_class = NULL;
+  GtkWindow *window = GTK_WINDOW (widget);
+  gboolean handled = FALSE;
+
+  if (grand_parent_class == NULL)
+    grand_parent_class = g_type_class_peek_parent (gtr_window_parent_class);
+
+  /* handle focus widget key events */
+  if (!handled)
+    handled = gtk_window_propagate_key_event (window, event);
+
+  /* handle mnemonics and accelerators */
+  if (!handled)
+    handled = gtk_window_activate_key (window, event);
+
+  /* Chain up, invokes binding set */
+  if (!handled)
+    handled = GTK_WIDGET_CLASS (grand_parent_class)->key_press_event (widget, event);
+
+  return handled;
+}
+#endif
+
 static void
 gtr_window_class_init (GtrWindowClass * klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
-  GtkObjectClass *gobject_class = GTK_OBJECT_CLASS (klass);
   GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
   g_type_class_add_private (klass, sizeof (GtrWindowPrivate));
@@ -1955,9 +2047,8 @@ gtr_window_class_init (GtrWindowClass * klass)
   object_class->finalize = gtr_window_finalize;
   object_class->dispose = gtr_window_dispose;
 
-  gobject_class->destroy = gtr_window_destroy;
-
   widget_class->configure_event = gtr_window_configure_event;
+  /*widget_class->key_press_event = gtr_window_key_press_event;*/
 }
 
 /***************************** Public funcs ***********************************/
@@ -1970,7 +2061,7 @@ gtr_window_class_init (GtrWindowClass * klass)
  * Adds a new #GtrTab to the #GtrNotebook and returns the
  * #GtrTab.
  * 
- * Returns: a new #GtrTab object
+ * Returns: (transfer none): a new #GtrTab object
  */
 GtrTab *
 gtr_window_create_tab (GtrWindow * window, GtrPo * po)
@@ -1991,7 +2082,7 @@ gtr_window_create_tab (GtrWindow * window, GtrPo * po)
  * 
  * Gets the active #GtrTab of the @window.
  *
- * Returns: the active #GtrTab of the @window.
+ * Returns: (transfer none): the active #GtrTab of the @window.
  */
 GtrTab *
 gtr_window_get_active_tab (GtrWindow * window)
@@ -2005,7 +2096,8 @@ gtr_window_get_active_tab (GtrWindow * window)
  *
  * Gets a list of all tabs in the @window or NULL if there is no tab opened.
  *
- * Returns: a list of all tabs in the @window or NULL if there is no tab opened.
+ * Returns: (transfer container): a list of all tabs in the @window or NULL if there
+ * is no tab opened.
  */
 GList *
 gtr_window_get_all_tabs (GtrWindow * window)
@@ -2036,7 +2128,7 @@ gtr_window_get_all_tabs (GtrWindow * window)
  * Gets the #GtrHeader of the #GtrPo of in the active
  * #GtrTab.
  *
- * Returns: the #GtrHeader of the #GtrPo of in the active
+ * Returns: (transfer none): the #GtrHeader of the #GtrPo of in the active
  * #GtrTab
  */
 GtrHeader *
@@ -2064,7 +2156,7 @@ gtr_window_get_header_from_active_tab (GtrWindow * window)
  * 
  * Gets the main #GtrNotebook of the @window.
  *
- * Returns: the #GtrNotebook of the @window
+ * Returns: (transfer none): the #GtrNotebook of the @window
  */
 GtrNotebook *
 gtr_window_get_notebook (GtrWindow * window)
@@ -2078,7 +2170,7 @@ gtr_window_get_notebook (GtrWindow * window)
  *
  * Gets the statusbar widget of the window.
  *
- * Returns: the statusbar widget of the window
+ * Returns: (transfer none): the statusbar widget of the window
  */
 GtkWidget *
 gtr_window_get_statusbar (GtrWindow * window)
@@ -2092,7 +2184,7 @@ gtr_window_get_statusbar (GtrWindow * window)
  *
  * Gets the #GtkUIManager of the window.
  *
- * Returns: the #GtkUIManager of the @window
+ * Returns: (transfer none): the #GtkUIManager of the @window
  */
 GtkUIManager *
 gtr_window_get_ui_manager (GtrWindow * window)
@@ -2107,8 +2199,8 @@ gtr_window_get_ui_manager (GtrWindow * window)
  * Gets the active translation view in the #GtranslationWindow or
  * NULL if there is not tab opened.
  *
- * Returns: the active translation view in the #GtranslationWindow or
- * NULL if there is not tab opened.
+ * Returns: (transfer none): the active translation view in the
+ *          #GtranslationWindow or %NULL if there is not tab opened.
  **/
 GtrView *
 gtr_window_get_active_view (GtrWindow * window)
@@ -2130,7 +2222,7 @@ gtr_window_get_active_view (GtrWindow * window)
  *
  * Returns all the views currently present in #GtranslationWindow
  *
- * Return value: a newly allocated list of #GtranslationWindow objects
+ * Return value: (transfer container): a newly allocated list of #GtranslationWindow objects
  **/
 GList *
 gtr_window_get_all_views (GtrWindow * window,
@@ -2215,14 +2307,14 @@ _gtr_window_get_layout_manager (GtrWindow * window)
 }
 
 /**
- * gtr_window_get_tab_from_uri:
+ * gtr_window_get_tab_from_location:
  * @window: a #GtrWindow
  * @location: the GFile of the po file of the #GtrTab
  *
  * Gets the #GtrTab of the #GtrWindows that matches with the
  * @location.
  *
- * Returns: the #GtrTab which @location matches with its po file.
+ * Returns: (transfer none): the #GtrTab which @location matches with its po file.
  */
 GtkWidget *
 gtr_window_get_tab_from_location (GtrWindow * window, GFile * location)
@@ -2302,6 +2394,12 @@ _gtr_window_close_tab (GtrWindow * window, GtrTab * tab)
   set_sensitive_according_to_window (window);
 }
 
+/**
+ * gtr_window_get_tm_menu:
+ * @window: a #GtrWindow
+ *
+ * Returns: (transfer none): get the tm_menu GtkWidget instance.
+ */
 GtkWidget *
 gtr_window_get_tm_menu (GtrWindow * window)
 {
